==> stapler_1.218.orig.tar.gz: stapler-stapler-parent-1.218/core/src/main/java/org/kohsuke/stapler/export/NotExportableException.java <==
/*
 * Copyright (c) 2004-2010, Kohsuke Kawaguchi
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice, this list of
 *       conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright notice, this list of
 *       conditions and the following disclaimer in the documentation and/or other materials
 *       provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.kohsuke.stapler.export;

/**
 * Signals an error that the class didn't have {@link ExportedBean}.
 *
 * @author Kohsuke Kawaguchi
 * @see Model
 */
public class NotExportableException extends IllegalArgumentException {
    private final Class type;

    public NotExportableException(Class type) {
        this(type+" doesn't have @"+ ExportedBean.class.getSimpleName(),type);
    }

    public NotExportableException(String s, Class type) {
        super(s);
        this.type = type;
    }

    public NotExportableException(String message, Throwable cause, Class type) {
        super(message, cause);
        this.type = type;
    }

    public NotExportableException(Throwable cause, Class type) {
        super(cause);
        this.type = type;
    }

    /**
     * Gets the type that didn't have {@link ExportedBean}
     */
    public Class getType() {
        return type;
    }
}

==> stapler_1.231.orig.tar.gz: stapler-stapler-parent-1.231/core/src/main/java/org/kohsuke/stapler/export/NotExportableException.java <==
/*
 * Copyright (c) 2004-2010, Kohsuke Kawaguchi
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice, this list of
 *       conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright notice, this list of
 *       conditions and the following disclaimer in the documentation and/or other materials
 *       provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.kohsuke.stapler.export;

/**
 * Signals an error that the class didn't have {@link ExportedBean}.
 *
 * @author Kohsuke Kawaguchi
 * @see Model
 */
public class NotExportableException extends IllegalArgumentException {
    private final Class type;

    public NotExportableException(Class type) {
        this(type+" doesn't have @"+ ExportedBean.class.getSimpleName(),type);
    }

    public NotExportableException(Class type, Class<?> propertyOwner, String property) {
        this(type + " doesn't have @" + ExportedBean.class.getSimpleName() + " so cannot write " + propertyOwner.getName() + '.' + property, type);
    }

    public NotExportableException(String s, Class type) {
        super(s);
        this.type = type;
    }

    public NotExportableException(String message, Throwable cause, Class type) {
        super(message, cause);
        this.type = type;
    }

    public NotExportableException(Throwable cause, Class type) {
        super(cause);
        this.type = type;
    }

    /**
     * Gets the type that didn't have {@link ExportedBean}
     */
    public Class getType() {
        return type;
    }
}
